==> nextcloud-26.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/ca.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Enllaç públic",
    "Photos" : "Fotografies",
    "Your memories under your control" : "Els vostres records sota control",
    "All media" : "Tot el contingut",
    "Videos" : "Vídeos",
    "Albums" : "Àlbums",
    "Collaborative albums" : "Àlbums col·laboratius",
    "People" : "Persones",
    "Folders" : "Carpetes",
    "Favorites" : "Preferits",
    "On this day" : "Aquest mateix dia",
    "Shared with you" : "Compartit amb vós",
    "Tags" : "Etiquetes",
    "Places" : "Llocs",
    "Map" : "Mapa",
    "Photos settings" : "Paràmetres de Fotografies",
    "Mark selection as favorite" : "Marca la selecció com a preferida",
    "Add selection to favorites" : "Afegeix la selecció als preferits",
    "Remove selection from favorites" : "Suprimeix la selecció dels preferits",
    "Name of the album" : "Nom de l'àlbum",
    "Location of the album" : "Lloc de l'àlbum",
    "Go back to the previous view." : "Torneu a la visualització anterior.",
    "Back" : "Torna",
    "Go to the add collaborators view." : "Aneu a la visualització Afegeix col·laboradors.",
    "Add collaborators" : "Afegeix col·laboradors",
    "Save." : "Desa.",
    "Create the album." : "Crea l'àlbum.",
    "Save" : "Desa",
    "Create album" : "Crea l'àlbum",
    "Back to the new album form." : "Torneu al formulari d'àlbum nou.",
    "Add to Album" : "Afegeix a l'àlbum",
    "Add selection to album {albumName}" : "Afegeix la selecció a l'àlbum {albumName}",
    "Create a new album." : "Creeu un àlbum nou.",
    "Create new album" : "Crea un àlbum",
    "New album" : "Àlbum nou",
    "_%n item_::_%n photos and videos_" : ["%n element","%n fotografies i vídeos"],
    "_Share with %n user_::_Share with %n users_" : ["Comparteix amb %n usuari","Comparteix amb %n usuaris"],
    "Add people or groups who can edit your album" : "Afegiu persones o grups que puguin editar l'àlbum",
    "Search for collaborators" : "Cerqueu col·laboradors",
    "Search people or groups" : "Cerqueu persones o grups",
    "Add {collaboratorLabel} to the collaborators list" : "Afegeix {collaboratorLabel} a la llista de col·laboradors",
    "No collaborators available" : "No hi ha cap col·laborador disponible",
    "Remove {collaboratorLabel} from the collaborators list" : "Suprimeix {collaboratorLabel} de la llista de col·laboradors",
    "Copy the public link" : "Copia l'enllaç públic",
    "Public link copied!" : "S'ha copiat l'enllaç públic!",
    "Copy public link" : "Copia l'enllaç públic",
    "Delete the public link" : "Suprimeix l'enllaç públic",
    "Share via public link" : "Comparteix mitjançant un enllaç públic",
    "Failed to fetch collaborators list." : "No s'ha pogut obtenir la llista de col·laboradors.",
    "Failed to fetch album." : "No s'ha pogut obtenir l'àlbum.",
    "Failed to update album." : "No s'ha pogut actualitzar l'àlbum.",
    "This collection does not exist" : "Aquesta col·lecció no existeix",
    "An error occurred" : "S'ha produït un error",
    "_%n photos_::_%n photos_" : ["%n fotografia","%n fotografies"],
    "Select image {imageName}" : "Selecciona la imatge {imageName}",
    "The file is in the favorites" : "El fitxer és en els preferits",
    "Open the full size \"{name}\" image" : "Obre la imatge «{name}» a mida completa",
    "There are no photos or videos yet!" : "Encara no hi ha cap fotografia ni vídeo!",
    "Add to {destination}" : "Afegeix a {destination}",
    "Open the \"{name}\" sub-directory" : "Obre la subcarpeta «{name}»",
    "Back to {folder}" : "Torna a {folder}",
    "Share this folder" : "Comparteix la carpeta",
    "_{years} year ago_::_{years} years ago_" : ["Fa {years} any","Fa {years} anys"],
    "Enable squared photos view" : "Habilita la visualització de fotografies quadrada",
    "Default Photos upload and Albums location" : "Ubicació per defecte de les pujades de fotografies i els àlbums",
    "Select the default location for your media" : "Seleccioneu la ubicació per defecte per al contingut multimèdia",
    "Invalid location selected" : "La ubicació seleccionada no és vàlida",
    "View" : "Visualització",
    "Photos directory" : "Carpeta de fotografies",
    "_%n photo_::_%n photos_" : ["%n fotografia","%n fotografies"],
    "Manage collaborators for this album" : "Administra els col·laboradors d'aquest àlbum",
    "Open actions menu" : "Obre el menú d'accions",
    "Edit album details" : "Edita els detalls de l'àlbum",
    "Download all files in album" : "Baixa tots els fitxers de l'àlbum",
    "Delete album" : "Suprimeix l'àlbum",
    "Download selected files" : "Baixa els fitxers seleccionats",
    "Remove selection from album" : "Suprimeix la selecció de l'àlbum",
    "This album does not have any photos or videos yet!" : "Aquest àlbum encara no té cap fotografia ni vídeo!",
    "Add photos to this album" : "Afegeix fotografies a aquest àlbum",
    "Add photos to the album" : "Afegeix fotografies a l'àlbum",
    "Manage collaborators" : "Administra els col·laboradors",
    "Save collaborators for this album." : "Deseu els col·laboradors per a aquest àlbum.",
    "Cover photo for album {albumName}" : "Foto de portada de l'àlbum {albumName}",
    "There is no album yet!" : "Encara no hi ha cap àlbum!",
    "This person could not be found" : "No s'ha pogut trobar aquesta persona",
    "Rename person" : "Canvia el nom de la persona",
    "Merge with different person" : "Fusiona amb una altra persona",
    "Download selected photos" : "Baixa les fotografies seleccionades",
    "Favorite" : "Afegeix als preferits",
    "Remove from favorites" : "Suprimeix dels preferits",
    "Remove person" : "Suprimeix la persona",
    "Name of this person" : "Nom d'aquesta persona",
    "Merge person" : "Fusiona la persona",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mou la fotografia a una altra persona","Mou les fotografies a una altra persona"],
    "_Remove photo from person_::_Remove photos from person_" : ["Suprimeix la fotografia de la persona","Suprimeix les fotografies de la persona"],
    "This might take some time depending on the size of your photo library." : "Això pot tardar una mica, en funció de la mida de la biblioteca de fotografies.",
    "Recognized people will show up here" : "Aquí apareixeran les persones reconegudes",
    "This folder does not exist" : "Aquesta carpeta no existeix",
    "Loading folders …" : "S'estan carregant les carpetes...",
    "No photos in here" : "No hi ha cap fotografia aquí",
    "This place does not have any photos or videos yet!" : "Aquest lloc encara no té cap fotografia ni vídeo!",
    "Add photos to this place" : "Afegeix fotografies a aquest lloc",
    "Cover photo for place {placeName}" : "Fotografia de portada del lloc {placeName}",
    "There is no place yet!" : "Encara no hi ha cap lloc!",
    "Failed to fetch albums list." : "No s'ha pogut obtenir la llista d'àlbums.",
    "Shared by" : "Compartit per",
    "Shared albums" : "Àlbums compartits",
    "Cover photo for shared album {albumName}." : "Fotografia de portada de l'àlbum compartit {albumName}.",
    "Back to tags overview" : "Torna a la visualització general d'etiquetes",
    "No photos with this tag yet" : "Encara no hi ha cap fotografia amb aquesta etiqueta",
    "No tags yet" : "Encara no hi ha cap etiqueta",
    "Photos with tags will show up here" : "Aquí apareixeran les fotografies amb etiquetes",
    "Popular tags" : "Etiquetes populars",
    "Add" : "Afegeix",
    "Create a new album" : "Crea un àlbum nou",
    "Add selection to an album" : "Afegeix la selecció a un àlbum",
    "Add to album" : "Afegeix a un àlbum",
    "Delete selection" : "Suprimeix la selecció",
    "No photos or videos in here" : "No hi ha cap fotografia ni vídeo aquí",
    "Failed to fetch collection." : "No s'ha pogut obtenir la col·lecció.",
    "Failed to fetch collections list." : "No s'ha pogut obtenir la llista de col·leccions.",
    "Failed to fetch faces list." : "No s'ha pogut obtenir la llista de cares.",
    "All your media" : "Tot el contingut",
    "Album {title}" : "Àlbum {title}",
    "Shared Albums" : "Àlbums compartits",
    "Shared album {title}" : "Àlbum compartit {title}",
    "Public album {title}" : "Àlbum públic {title}",
    "Tagged photos" : "Fotografies etiquetades",
    "Tagged photo {title}" : "Fotografia etiquetada {title}",
    "{title}'s face" : "Cara de {title}",
    "Failed to create {albumName}." : "No s'ha pogut crear {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "No s'ha pogut canviar el nom de l'àlbum {currentAlbumName} a {newAlbumName}.",
    "Failed to rename {oldName} to {faceName}." : "No s'ha pogut canviar el nom de la persona {oldName} a {faceName}.",
    "Failed to delete {faceName}." : "No s'ha pogut suprimir {faceName}.",
    "Failed to delete {fileId}." : "No s'ha pogut suprimir {fileId}.",
    "Failed to delete {fileName}." : "No s'ha pogut suprimir {fileName}.",
    "Failed to set favorite state for {fileId}." : "No s'ha pogut establir l'estat de preferit per a {fileId}.",
    "Failed to set favorite state for {fileName}." : "No s'ha pogut establir l'estat de preferit per a {fileName}.",
    "Your photos" : "Les vostres fotografies",
    "Your videos" : "Els vostres vídeos",
    "Your folders" : "Les vostres carpetes",
    "Locations" : "Llocs",
    "Settings" : "Paràmetres"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/ca.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Enllaç públic",
    "Photos" : "Fotografies",
    "Your memories under your control" : "Els vostres records sota control",
    "All media" : "Tot el contingut",
    "Videos" : "Vídeos",
    "Albums" : "Àlbums",
    "Collaborative albums" : "Àlbums col·laboratius",
    "People" : "Persones",
    "Folders" : "Carpetes",
    "Favorites" : "Preferits",
    "On this day" : "Aquest mateix dia",
    "Shared with you" : "Compartit amb vós",
    "Tags" : "Etiquetes",
    "Places" : "Llocs",
    "Map" : "Mapa",
    "Photos settings" : "Paràmetres de Fotografies",
    "Mark selection as favorite" : "Marca la selecció com a preferida",
    "Add selection to favorites" : "Afegeix la selecció als preferits",
    "Remove selection from favorites" : "Suprimeix la selecció dels preferits",
    "Name of the album" : "Nom de l'àlbum",
    "Location of the album" : "Lloc de l'àlbum",
    "Go back to the previous view." : "Torneu a la visualització anterior.",
    "Back" : "Torna",
    "Go to the add collaborators view." : "Aneu a la visualització Afegeix col·laboradors.",
    "Add collaborators" : "Afegeix col·laboradors",
    "Save." : "Desa.",
    "Create the album." : "Crea l'àlbum.",
    "Save" : "Desa",
    "Create album" : "Crea l'àlbum",
    "Back to the new album form." : "Torneu al formulari d'àlbum nou.",
    "Add to Album" : "Afegeix a l'àlbum",
    "Add selection to album {albumName}" : "Afegeix la selecció a l'àlbum {albumName}",
    "Shared by" : "Compartit per",
    "Create a new album." : "Creeu un àlbum nou.",
    "Create new album" : "Crea un àlbum",
    "New album" : "Àlbum nou",
    "_%n item_::_%n photos and videos_" : ["%n element","%n fotografies i vídeos"],
    "Add people or groups who can edit your album" : "Afegiu persones o grups que puguin editar l'àlbum",
    "Search people or groups" : "Cerqueu persones o grups",
    "No recommendations. Start typing." : "No hi ha cap recomanació. Comenceu a escriure.",
    "Group" : "Grup",
    "Remove {collaboratorLabel} from the collaborators list" : "Suprimeix {collaboratorLabel} de la llista de col·laboradors",
    "Copy the public link" : "Copia l'enllaç públic",
    "Public link copied!" : "S'ha copiat l'enllaç públic!",
    "Copy public link" : "Copia l'enllaç públic",
    "Delete the public link" : "Suprimeix l'enllaç públic",
    "Create public link share" : "Crea un element compartit per enllaç públic",
    "Share via public link" : "Comparteix mitjançant un enllaç públic",
    "Failed to fetch collaborators list." : "No s'ha pogut obtenir la llista de col·laboradors.",
    "Failed to update album." : "No s'ha pogut actualitzar l'àlbum.",
    "This collection does not exist" : "Aquesta col·lecció no existeix",
    "An error occurred" : "S'ha produït un error",
    "_%n photos_::_%n photos_" : ["%n fotografia","%n fotografies"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n fotografia sense assignar","%n fotografies sense assignar"],
    "Select image {imageName}" : "Selecciona la imatge {imageName}",
    "The file is in the favorites" : "El fitxer és en els preferits",
    "Open the full size \"{name}\" image" : "Obre la imatge «{name}» a mida completa",
    "There are no photos or videos yet!" : "Encara no hi ha cap fotografia ni vídeo!",
    "Add to {destination}" : "Afegeix a {destination}",
    "Open the \"{name}\" sub-directory" : "Obre la subcarpeta «{name}»",
    "Back to {folder}" : "Torna a {folder}",
    "Share this folder" : "Comparteix la carpeta",
    "_{years} year ago_::_{years} years ago_" : ["Fa {years} any","Fa {years} anys"],
    "Enable squared photos view" : "Habilita la visualització de fotografies quadrada",
    "Default Photos upload and Albums location" : "Ubicació per defecte de les pujades de fotografies i els àlbums",
    "Choose default Photos upload and Albums location" : "Tria la ubicació per defecte de les pujades de fotografies i dels àlbums",
    "Select the default location for your media" : "Seleccioneu la ubicació per defecte per al contingut multimèdia",
    "Invalid location selected" : "La ubicació seleccionada no és vàlida",
    "View" : "Visualització",
    "Photos directory" : "Carpeta de fotografies",
    "_%n photo_::_%n photos_" : ["%n fotografia","%n fotografies"],
    "Unselect all" : "Anul·la tota la selecció",
    "Manage collaborators for this album" : "Administra els col·laboradors d'aquest àlbum",
    "Open actions menu" : "Obre el menú d'accions",
    "Edit album details" : "Edita els detalls de l'àlbum",
    "Download all files in album" : "Baixa tots els fitxers de l'àlbum",
    "Delete album" : "Suprimeix l'àlbum",
    "Download selected files" : "Baixa els fitxers seleccionats",
    "Remove selection from album" : "Suprimeix la selecció de l'àlbum",
    "This album does not have any photos or videos yet!" : "Aquest àlbum encara no té cap fotografia ni vídeo!",
    "Add photos to this album" : "Afegeix fotografies a aquest àlbum",
    "Add photos to {albumName}" : "Afegeix fotografies a {albumName}",
    "Manage collaborators" : "Administra els col·laboradors",
    "Save collaborators for this album." : "Deseu els col·laboradors per a aquest àlbum.",
    "Cover photo for album {albumName}" : "Foto de portada de l'àlbum {albumName}",
    "There is no album yet!" : "Encara no hi ha cap àlbum!",
    "This person could not be found" : "No s'ha pogut trobar aquesta persona",
    "Rename person" : "Canvia el nom de la persona",
    "Merge with different person" : "Fusiona amb una altra persona",
    "Download selected photos" : "Baixa les fotografies seleccionades",
    "Favorite" : "Afegeix als preferits",
    "Remove from favorites" : "Suprimeix dels preferits",
    "Remove person" : "Suprimeix la persona",
    "Name of this person" : "Nom d'aquesta persona",
    "Merge person" : "Fusiona la persona",
    "Move to different person" : "Mou a una altra persona",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mou la fotografia a una altra persona","Mou les fotografies a una altra persona"],
    "_Remove photo from person_::_Remove photos from person_" : ["Suprimeix la fotografia de la persona","Suprimeix les fotografies de la persona"],
    "This might take some time depending on the size of your photo library." : "Això pot tardar una mica, en funció de la mida de la biblioteca de fotografies.",
    "Recognized people will show up here" : "Aquí apareixeran les persones reconegudes",
    "This folder does not exist" : "Aquesta carpeta no existeix",
    "Loading folders …" : "S'estan carregant les carpetes…",
    "No photos in here" : "No hi ha cap fotografia aquí",
    "This place does not have any photos or videos yet!" : "Aquest lloc encara no té cap fotografia ni vídeo!",
    "Add photos to this place" : "Afegeix fotografies a aquest lloc",
    "Cover photo for place {placeName}" : "Fotografia de portada del lloc {placeName}",
    "There is no place yet!" : "Encara no hi ha cap lloc!",
    "Cover photo for shared album {albumName}." : "Fotografia de portada de l'àlbum compartit {albumName}.",
    "Back to tags overview" : "Torna a la visualització general d'etiquetes",
    "No photos with this tag yet" : "Encara no hi ha cap fotografia amb aquesta etiqueta",
    "No tags yet" : "Encara no hi ha cap etiqueta",
    "Photos with tags will show up here" : "Aquí apareixeran les fotografies amb etiquetes",
    "Popular tags" : "Etiquetes populars",
    "Add" : "Afegeix",
    "Add to album" : "Afegeix a un àlbum",
    "Delete selection" : "Suprimeix la selecció",
    "No photos or videos in here" : "No hi ha cap fotografia ni vídeo aquí",
    "Unassigned faces" : "Cares sense assignar",
    "Failed to fetch collection." : "No s'ha pogut obtenir la col·lecció.",
    "Failed to fetch collections list." : "No s'ha pogut obtenir la llista de col·leccions.",
    "Failed to fetch faces list." : "No s'ha pogut obtenir la llista de cares.",
    "All your media" : "Tot el contingut",
    "Album {title}" : "Àlbum {title}",
    "Shared Albums" : "Àlbums compartits",
    "Shared album {title}" : "Àlbum compartit {title}",
    "Public album {title}" : "Àlbum públic {title}",
    "Tagged photos" : "Fotografies etiquetades",
    "Tagged photo {title}" : "Fotografia etiquetada {title}",
    "{title}'s face" : "Cara de {title}",
    "Failed to rename {oldName} to {faceName}." : "No s'ha pogut canviar el nom de la persona {oldName} a {faceName}.",
    "Failed to delete {faceName}." : "No s'ha pogut suprimir {faceName}.",
    "Failed to delete {fileId}." : "No s'ha pogut suprimir {fileId}.",
    "Failed to delete {fileName}." : "No s'ha pogut suprimir {fileName}.",
    "Failed to set favorite state for {fileId}." : "No s'ha pogut establir l'estat de preferit per a {fileId}.",
    "Failed to set favorite state for {fileName}." : "No s'ha pogut establir l'estat de preferit per a {fileName}.",
    "Locations" : "Llocs",
    "_Share with %n user_::_Share with %n users_" : ["Comparteix amb %n usuari","Comparteix amb %n usuaris"],
    "Search for collaborators" : "Cerqueu col·laboradors",
    "Add {collaboratorLabel} to the collaborators list" : "Afegeix {collaboratorLabel} a la llista de col·laboradors",
    "No collaborators available" : "No hi ha cap col·laborador disponible",
    "Failed to fetch album." : "No s'ha pogut obtenir l'àlbum.",
    "Add photos to the album" : "Afegeix fotografies a l'àlbum",
    "Failed to fetch albums list." : "No s'ha pogut obtenir la llista d'àlbums.",
    "Shared albums" : "Àlbums compartits",
    "Create a new album" : "Crea un àlbum nou",
    "Add selection to an album" : "Afegeix la selecció a un àlbum",
    "Failed to create {albumName}." : "No s'ha pogut crear {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "No s'ha pogut canviar el nom de l'àlbum {currentAlbumName} a {newAlbumName}."
},
"nplurals=2; plural=(n != 1);");
